tietools.iterate_tie_chains_backward_in_expr
============================================

.. autofunction:: abjad.tools.tietools.iterate_tie_chains_backward_in_expr.iterate_tie_chains_backward_in_expr
